#ifndef MID812_CONST_H
#define MID812_CONST_H


#ifdef ISDLLBUILD
    #define MID812_API extern "C" __declspec(dllexport)
#else
#ifdef __cplusplus
    #define MID812_API extern "C" __declspec(dllimport)
#else
    #define MID812_API __declspec(dllimport)
#endif
#endif



// error constants
#define MID812_SUCCESS             0
#define MID812_ERR_NONE            0
#define MID812_ERR_UNSPECIFIED     -1
#define MID812_ERR_CAPTURING       -2   // already capturing/recording
#define MID812_ERR_NOTCAPTURING    -3   // not capturing/recording
#define MID812_ERR_RUNNING         -4   // attempt to set configuration while graph running
#define MID812_ERR_SNAPSHOT        -5   // currently displaying snapshot
#define MID812_ERR_INVALIDFILE     -6   // invalid file
#define MID812_ERR_DIRECTX         -7   // directX error( other specific directX errors are possible)
#define MID812_ERR_NODEVICE		-8   // device not present
#define MID812_ERR_NOTINITIALIZED  -9	 // initialization function failed or not called
#define MID812_ERR_INVALIDMODE    -10  // invalid mode(eg.  record in MJPEG CAPTURE mode)

typedef enum
{
	MID812_VIDSYS_PAL = 1,
	MID812_VIDSYS_NTSC = 2
} MID812_VIDSYS;


typedef enum
{
	MID812_COLORSPACE_YUY2 = 0,// aka YUYV
    MID812_COLORSPACE_UYVY = 1, 
	MID812_COLORSPACE_RGB565 = 2,
    MID812_COLORSPACE_I420 = 3,
} MID812_COLORSPACE;


/** VIDEO levels */
#define MID812_LEVEL_CONTRAST		1
#define	MID812_LEVEL_BRIGHTNESS	    2
#define MID812_LEVEL_SATURATION	    4
#define MID812_LEVEL_HUE			8
#define MID812_CONTRAST_MIN 0
#define MID812_CONTRAST_MAX 255
#define MID812_CONTRAST_DEF 100
#define MID812_BRIGHTNESS_MIN -128
#define MID812_BRIGHTNESS_MAX 127
#define MID812_BRIGHTNESS_DEF 0
#define MID812_HUE_MIN -128
#define MID812_HUE_MAX 127
#define MID812_HUE_DEF 0
#define MID812_SATURATION_MIN 0
#define MID812_SATURATION_MAX 255
#define MID812_SATURATION_DEF 128

// image file save bitmask types 
 
#define	MID812_FILE_JPEG		1
#define	MID812_FILE_BMP			2
#define	MID812_FILE_PPM			4

/** Resolutions
 *  D1  -- 720x 480 NTSC, 720x576 PAL
 *  SIF -- 352 x 240  // NTSC only
 *  CIF -- 352 x 288  // PAL only
 *  VGA -- 640x480
 *  4SIF -- 704x480 // NTSC only
 *  4CIF -- 704x576 // PAL only
 */
typedef enum
{
	MID812_RES_D1 = 0,
	MID812_RES_SIF,  // NTSC only
    MID812_RES_CIF,  // PAL only
    MID812_RES_VGA,
    MID812_RES_4SIF, // NTSC
    MID812_RES_4CIF, // PAL
}  MID812_RES;

typedef enum
{
    MID812_VMR9,
    MID812_VMR7,
    MID812_DSHOW_LEGACY, // not recommended
}  MID812_DSHOW;

// secondary errors from S812_GetDebugErrorCode
#define S812_SDKERR_CREATE_INSTANCE -1000
#define S812_SDKERR_ADD_DEVICE      -1001
#define S812_SDKERR_VMR -1002
#define S812_SDKERR_VMR9 -1003
#define S812_SDKERR_FILTERGRAPH -1004
#define S812_SDKERR_ADD_AVCAPTURE -1005
#define S812_SDKERR_ADD_AUDIOCAPTURE -1006
#define S812_SDKERR_ADD_AVIDECOMP -1007
#define S812_SDKERR_ADD_DEINTERLACE -1008
#define S812_SDKERR_AVCAP_TO_TEE -1009
#define S812_SDKERR_ADD_SNAPSHOT -1010
#define S812_SDKERR_TEE_TO_SNAPSHOT -1011
#define S812_SDKERR_TEE_TO_AVIDECOMP -1012
#define S812_SDKERR_LEGACY -1013
#define S812_SDKERR_VIDRENDER -1014
#define S812_SDKERR_AVI_TO_RENDER -1015
#define S812_SDKERR_TEE_TO_RENDER -1016
#define S812_SDKERR_MUXER -1017
#define S812_SDKERR_WRITER -1018
#define S812_SDKERR_SNAP_TO_MUXER -1019
#define S812_SDKERR_TEE_TO_MUXER -1020
#define S812_SDKERR_AUDIO_TO_MUXER -1021 
#define S812_SDKERR_MUX_TO_WRITER -1022
#define S812_SDKERR_LEGACY_RENDER -1023
#define S812_SDKERR_VIDDECODER -1025
#define S812_SDKERR_CAPTURE_TO_SNAPSHOT -1026
#define S812_SDKERR_DECOMP_TO_RENDER -1027
#define S812_SDKERR_DECOMP -1028
#define S812_SDKERR_DECOMP_TO_RENDER2 -1030
#define S812_SDKERR_DECOMP_TO_RENDER3 -1033
#define S812_SDKERR_AVCAP_TO_RENDER -1034
#define S812_SDKERR_START_GRAPH -1035
#define S812_SDKERR_SNAPSHOT_TO_DECOMP1 -1036
#define S812_SDKERR_SNAPSHOT_TO_DECOMP2 -1037


#endif
